Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/render/state.h')
-rw-r--r--src/render/state.h42
1 files changed, 29 insertions, 13 deletions
diff --git a/src/render/state.h b/src/render/state.h
index ea55602..0581c2e 100644
--- a/src/render/state.h
+++ b/src/render/state.h
@@ -75,36 +75,51 @@ public:
static void set_power(const bool power);
/**
* @brief Set the material context
* use_material() will alter the current render context according to the settings
* defined by the material. If the material uses primary, secondary or engine color,
* the current material context colors will be used.
**/
- static void use_material(const model::Material * material);
+ static void use_material_layer(const model::Material * material, const model::Layer *layer);
- inline static int width() {
+ inline static int width()
+ {
return state_width;
}
- inline static int height() {
+
+ inline static int height()
+ {
return state_height;
}
- inline static float aspect() {
+
+ inline static float aspect()
+ {
return state_aspect;
}
- inline static bool has_generate_mipmaps() {
+
+ inline static bool has_generate_mipmaps()
+ {
return state_has_generate_mipmaps;
}
- inline static bool has_vbo() {
+
+ inline static bool has_vbo()
+ {
return state_has_vbo;
}
- inline static GLuint vbo() {
+
+ inline static GLuint vbo()
+ {
return state_vbo;
}
- inline static int max_lights() {
+
+ inline static int max_lights()
+ {
return state_maxlights;
}
- inline static int max_textureunits() {
+
+ inline static int max_textureunits()
+ {
return state_maxtextureunits;
}
@@ -120,6 +135,7 @@ private:
static GLuint state_vbo;
static int state_maxlights;
static int state_maxtextureunits;
+ static size_t state_logo_texture_id;
static math::Color state_color_primary; // current primary color
static math::Color state_color_secondary; // current secondary color
@@ -75,36 +75,51 @@ public:
static void set_power(const bool power);
/**
- * @brief Set the material context
- * use_material() will alter the current render context according to the settings
- * defined by the material. If the material uses primary, secondary or engine color,
- * the current material context colors will be used.
+ * @brief set the material layer context
+ * use_material_layer() will alter the current render context according to the settings
+ * defined by the material layer. If the material uses primary, secondary or engine color,
+ * the current state context colors will be used.
**/